@@ -16,6 +16,7 @@
 
 #include <QtGlobal>
 
+class QDateTime;
 class QStringList;
 class QColor;
 
@@ -34,7 +35,10 @@ public:
      */
     Planet();
 
-    MARBLE_DEPRECATED( explicit Planet( const QString& id ) ); // please use PlanetFactory::construct(id) instead
+    /**
+     * @deprecated Please use PlanetFactory::construct(id) instead.
+     */
+    MARBLE_DEPRECATED explicit Planet(const QString& id);
 
     ///Copy Constructor
     Planet( const Planet& other );
@@ -67,11 +71,23 @@ public:
     /// the radius of the planet, in metres
     qreal radius() const;
 
+    /// the twilight zone of the planet, in radians
+    qreal twilightZone() const;
+
     /** The user visible name of the planet */
     QString name() const;
     /** The internal, nonlocalized name of the planet */
     QString id() const;
 
+    /**
+     * Fills the longitude and latitude with the planet's sun position.
+     *
+     * @param lon the longitude of the sun, in radian
+     * @param lat the latitude of the sun, in radian
+     * @param dateTime the time for which the sun position is to be calculated
+     */
+    void sunPosition(qreal &lon, qreal &lat, const QDateTime &dateTime) const;
+
     /* Setter functions */
     void setM_0( qreal M_0 );
     void setM_1( qreal M_1 );
@@ -92,13 +108,21 @@ public:
 
     void setRadius( qreal radius );
 
+    void setTwilightZone(qreal twilightZone);
+
     void setName( const QString& name );
     void setId( const QString& id );
 
     Planet& operator=( const Planet& rhs );
 
-    MARBLE_DEPRECATED( static QString name( const QString& id ) ); // please use PlanetFactory::localizedName(id) instead
-    MARBLE_DEPRECATED( static QStringList planetList() );  // please use PlanetFactory::planetList() instead
+    /**
+     * @deprecated Please use PlanetFactory::localizedName(id) instead.
+     */
+    MARBLE_DEPRECATED static QString name(const QString& id);
+    /**
+     * @deprecated Please use PlanetFactory::planetList() instead.
+     */
+    MARBLE_DEPRECATED static QStringList planetList();
 
     bool hasAtmosphere() const;
     void setHasAtmosphere( bool enabled );
